@@ -6,8 +6,4 @@ use RPi::ADC::ADS;
 
 my $o = RPi::ADC::ADS->new;
 
-say $o->volts(0);
-say $o->volts(3);
-
-say $o->percent(0);
-say $o->percent(5);
+printf("%b\n", $o->bits);
